From `The Python Language Reference – The import statement <https://docs.python.org/3/reference/simple_stmts.html#the-import-statement>`_:
    "The `public names` defined by a module are determined by checking the module's namespace for a variable named ``__all__``; if defined, it must be a sequence of strings which are names defined or imported by that module."
